@@ -14,8 +14,8 @@ from .gldrawable import GLDrawable
 class BackgroundGL(GLDrawable):
     def __init__(self, element=None, *args, **kwargs):
         super().__init__(element, *args, **kwargs)
-        self._top_color = [0.1, 0.2, 0.3]
-        self._bottom_color = [0.4, 0.5, 0.6]
+        self._top_color = [0.1, 0.2, 0.3, 1.0]
+        self._bottom_color = [0.4, 0.5, 0.6, 1.0]
 
     @property
     def top_color(self) -> list:
