@@ -144,12 +144,12 @@ class ActionCollection:
 
         self.action_cross_section = QAction('&Cross-section', parent)
         self.action_cross_section.setIcon(IconCollection.get('flash_on.svg'))
-        self.action_cross_section.setShortcut('Ctrl+Shift+C')
+        self.action_cross_section.setShortcut('Ctrl+Shift+S')
         self.action_cross_section.setCheckable(True)
 
-        self.action_camera_properties = QAction('&Camera properties', parent)
-        self.action_camera_properties.setIcon(IconCollection.get('compact_camera.svg'))
-        self.action_camera_properties.setShortcut('Ctrl+C')
+        self.action_viewer_properties = QAction('&Viewer properties', parent)
+        self.action_viewer_properties.setIcon(IconCollection.get('compact_camera.svg'))
+        self.action_viewer_properties.setShortcut('Ctrl+C')
 
         self.action_plan_view = QAction('&Plan view', parent)
         self.action_plan_view.setIcon(IconCollection.get('upload.svg'))
